"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FixedWidthRecord_1 = require("../../../src/feed/record/FixedWidthRecord");
const MultiRecordFile_1 = require("../../../src/feed/file/MultiRecordFile");
const TextField_1 = require("../../../src/feed/field/TextField");
const DateField_1 = require("../../../src/feed/field/DateField");
const IntField_1 = require("../../../src/feed/field/IntField");
const Record_1 = require("../../../src/feed/record/Record");
const supplement = new FixedWidthRecord_1.FixedWidthRecord("supplement", ["supplement_code", "end_date"], {
    "supplement_code": new TextField_1.TextField(2, 3),
    "end_date": new DateField_1.DateField(5),
    "start_date": new DateField_1.DateField(13),
    "quote_date": new DateField_1.DateField(21),
    "description": new TextField_1.TextField(29, 20),
    "short_desc": new TextField_1.TextField(49, 12),
    "suppl_type": new TextField_1.TextField(61, 3),
    "price": new IntField_1.IntField(64, 5, false, [" ", "*"]),
    "cpf_ticket_type": new TextField_1.TextField(69, 5, true),
    "min_group_size": new IntField_1.IntField(74, 1),
    "max_group_size": new IntField_1.IntField(75, 1),
    "per_leg_or_dir": new TextField_1.TextField(76, 1),
    "class_type": new TextField_1.TextField(77, 1),
    "capri_code": new TextField_1.TextField(78, 3, true),
    "sep_tkt_ind": new TextField_1.TextField(81, 1),
    "resvn_type": new TextField_1.TextField(82, 2),
    "sundry_code": new IntField_1.ZeroFillIntField(84, 5, true)
}, [], {
    "I": Record_1.RecordAction.Insert,
    "A": Record_1.RecordAction.Update,
    "D": Record_1.RecordAction.Delete,
    "R": Record_1.RecordAction.Insert
});
const supplementRule = new FixedWidthRecord_1.FixedWidthRecord("supplement_rule", ["rule_number", "end_date"], {
    "rule_number": new IntField_1.IntField(2, 3, false, []),
    "end_date": new DateField_1.DateField(5),
    "start_date": new DateField_1.DateField(13),
    "quote_date": new DateField_1.DateField(21),
    "train_uid": new TextField_1.TextField(29, 7, true),
    "train_uid_desc": new TextField_1.TextField(36, 39, true),
    "fare_class": new TextField_1.TextField(75, 1, false, []),
    "quota": new TextField_1.TextField(76, 1, false, []),
    "weekend_first": new TextField_1.TextField(77, 1, false, []),
    "silver_standard": new TextField_1.TextField(78, 1, false, []),
    "railcard": new TextField_1.TextField(79, 1, false, []),
    "catering_code": new TextField_1.TextField(80, 1, false, []),
    "sleeper": new TextField_1.TextField(81, 1, false, []),
    "accom_class": new TextField_1.TextField(82, 1, false, []),
    "status": new TextField_1.TextField(83, 1),
    "reservation_status": new TextField_1.TextField(84, 3, true),
    "sectors": new TextField_1.TextField(87, 3, true)
}, [], {
    "I": Record_1.RecordAction.Insert,
    "A": Record_1.RecordAction.Update,
    "D": Record_1.RecordAction.Delete,
    "R": Record_1.RecordAction.Insert
});
const supplementRuleApplies = new FixedWidthRecord_1.FixedWidthRecord("supplement_rule_applies", ["rule_number", "end_date", "ie_marker", "condition_type", "ie_code"], {
    "rule_number": new IntField_1.IntField(2, 3, false, []),
    "end_date": new DateField_1.DateField(5),
    "ie_marker": new TextField_1.TextField(13, 1),
    "condition_type": new TextField_1.TextField(14, 1),
    "ie_code": new TextField_1.TextField(15, 3)
}, [], {
    "I": Record_1.RecordAction.Insert,
    "A": Record_1.RecordAction.Update,
    "D": Record_1.RecordAction.Delete,
    "R": Record_1.RecordAction.Insert
});
const supplementRuleSupplement = new FixedWidthRecord_1.FixedWidthRecord("supplement_rule_supplement", ["rule_number", "end_date", "supplement_code"], {
    "rule_number": new IntField_1.IntField(2, 3, false, []),
    "end_date": new DateField_1.DateField(5),
    "supplement_code": new TextField_1.TextField(13, 3),
    "om_flag": new TextField_1.TextField(16, 1)
}, [], {
    "I": Record_1.RecordAction.Insert,
    "A": Record_1.RecordAction.Update,
    "D": Record_1.RecordAction.Delete,
    "R": Record_1.RecordAction.Insert
});
const supplementOverride = new FixedWidthRecord_1.FixedWidthRecord("supplement_override", ["supplement_code", "end_date", "overridden_supplement"], {
    "supplement_code": new TextField_1.TextField(2, 3),
    "end_date": new DateField_1.DateField(5),
    "overridden_supplement": new TextField_1.TextField(13, 3)
}, [], {
    "I": Record_1.RecordAction.Insert,
    "A": Record_1.RecordAction.Update,
    "D": Record_1.RecordAction.Delete,
    "R": Record_1.RecordAction.Insert
});
const SUP = new MultiRecordFile_1.MultiRecordFile({
    "S": supplement,
    "R": supplementRule,
    "A": supplementRuleApplies,
    "M": supplementRuleSupplement,
    "O": supplementOverride
});
exports.default = SUP;
//# sourceMappingURL=SUP.js.map