"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extraDetails = void 0;
const FixedWidthRecord_1 = require("../../../src/feed/record/FixedWidthRecord");
const TextField_1 = require("../../../src/feed/field/TextField");
const MultiRecordFile_1 = require("../../../src/feed/file/MultiRecordFile");
const BooleanField_1 = require("../../../src/feed/field/BooleanField");
const DateField_1 = require("../../../src/feed/field/DateField");
const ForeignKeyField_1 = require("../../../src/feed/field/ForeignKeyField");
const TimeField_1 = require("../../../src/feed/field/TimeField");
const MultiFormatRecord_1 = require("../../../src/feed/record/MultiFormatRecord");
const schedule = new FixedWidthRecord_1.RecordWithManualIdentifier("z_schedule", ["train_uid", "runs_from", "stp_indicator"], {
    "train_uid": new TextField_1.TextField(3, 6),
    "runs_from": new DateField_1.ShortDateField(9),
    "runs_to": new DateField_1.ShortDateField(15),
    "monday": new BooleanField_1.BooleanField(21),
    "tuesday": new BooleanField_1.BooleanField(22),
    "wednesday": new BooleanField_1.BooleanField(23),
    "thursday": new BooleanField_1.BooleanField(24),
    "friday": new BooleanField_1.BooleanField(25),
    "saturday": new BooleanField_1.BooleanField(26),
    "sunday": new BooleanField_1.BooleanField(27),
    "bank_holiday_running": new BooleanField_1.BooleanField(28, false, ["X"], [" "], []),
    "train_status": new TextField_1.TextField(29, 1, true),
    "train_category": new TextField_1.TextField(30, 2, true),
    "train_identity": new TextField_1.TextField(32, 4, true),
    "headcode": new TextField_1.TextField(36, 4, true),
    "course_indicator": new TextField_1.TextField(40, 1, true),
    "profit_center": new TextField_1.TextField(41, 8, true),
    "business_sector": new TextField_1.TextField(49, 1, true),
    "power_type": new TextField_1.TextField(50, 3, true),
    "timing_load": new TextField_1.TextField(53, 4, true),
    "speed": new TextField_1.TextField(57, 3, true),
    "operating_chars": new TextField_1.TextField(60, 6, true),
    "train_class": new TextField_1.TextField(66, 1, true),
    "sleepers": new TextField_1.TextField(67, 1, true),
    "reservations": new TextField_1.TextField(68, 1, true),
    "connect_indicator": new TextField_1.TextField(69, 1, true),
    "catering_code": new TextField_1.TextField(70, 4, true),
    "service_branding": new TextField_1.TextField(74, 4, true),
    "stp_indicator": new TextField_1.TextField(79, 1)
}, ["runs_from"]);
exports.extraDetails = new FixedWidthRecord_1.FixedWidthRecord("z_schedule_extra", [], {
    "schedule": new ForeignKeyField_1.ForeignKeyField(schedule),
    "atoc_code": new TextField_1.TextField(11, 2, true),
}, ["schedule"]);
const stopRecordTypes = {
    "LO": {
        "z_schedule": new ForeignKeyField_1.ForeignKeyField(schedule),
        "location": new TextField_1.TextField(2, 3),
        "scheduled_arrival_time": new TimeField_1.TimeField(43, 5),
        "scheduled_departure_time": new TimeField_1.TimeField(10, 5),
        "scheduled_pass_time": new TimeField_1.TimeField(43, 5),
        "public_arrival_time": new TimeField_1.TimeField(43, 4),
        "public_departure_time": new TimeField_1.TimeField(15, 4),
        "platform": new TextField_1.TextField(19, 3, true),
        "line": new TextField_1.TextField(22, 3, true),
        "path": new TextField_1.TextField(43, 3, true),
        "activity": new TextField_1.VariableLengthText(29, 12, false, []),
        "engineering_allowance": new TextField_1.TextField(25, 2, true),
        "pathing_allowance": new TextField_1.TextField(27, 2, true),
        "performance_allowance": new TextField_1.TextField(41, 2, true)
    },
    "LI": {
        "z_schedule": new ForeignKeyField_1.ForeignKeyField(schedule),
        "location": new TextField_1.TextField(2, 3),
        "scheduled_arrival_time": new TimeField_1.TimeField(10, 5),
        "scheduled_departure_time": new TimeField_1.TimeField(15, 5),
        "scheduled_pass_time": new TimeField_1.TimeField(20, 5),
        "public_arrival_time": new TimeField_1.TimeField(25, 4),
        "public_departure_time": new TimeField_1.TimeField(29, 4),
        "platform": new TextField_1.TextField(33, 3, true),
        "line": new TextField_1.TextField(36, 3, true),
        "path": new TextField_1.TextField(39, 3, true),
        "activity": new TextField_1.VariableLengthText(42, 12, false, []),
        "engineering_allowance": new TextField_1.TextField(54, 2, true),
        "pathing_allowance": new TextField_1.TextField(56, 2, true),
        "performance_allowance": new TextField_1.TextField(58, 2, true)
    },
    "LT": {
        "z_schedule": new ForeignKeyField_1.ForeignKeyField(schedule),
        "location": new TextField_1.TextField(2, 3),
        "scheduled_arrival_time": new TimeField_1.TimeField(10, 5),
        "scheduled_departure_time": new TimeField_1.TimeField(43, 5),
        "scheduled_pass_time": new TimeField_1.TimeField(43, 5),
        "public_arrival_time": new TimeField_1.TimeField(15, 4),
        "public_departure_time": new TimeField_1.TimeField(43, 4),
        "platform": new TextField_1.TextField(19, 3, true),
        "line": new TextField_1.TextField(43, 3, true),
        "path": new TextField_1.TextField(22, 3, true),
        "activity": new TextField_1.VariableLengthText(25, 12, false, []),
        "engineering_allowance": new TextField_1.TextField(54, 2, true),
        "pathing_allowance": new TextField_1.TextField(56, 2, true),
        "performance_allowance": new TextField_1.TextField(58, 2, true)
    }
};
const stop = new MultiFormatRecord_1.MultiFormatRecord("z_stop_time", ["z_schedule", "location", "public_departure_time"], stopRecordTypes.LI, stopRecordTypes, 0, 2, [], true);
const ZTR = new MultiRecordFile_1.MultiRecordFile({
    "BS": schedule,
    "BX": exports.extraDetails,
    "LO": stop,
    "LI": stop,
    "LT": stop
}, 0, 2);
exports.default = ZTR;
//# sourceMappingURL=ZTR.js.map