"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Container = void 0;
const memoize = require("memoized-class-decorator");
const ImportFeedCommand_1 = require("./ImportFeedCommand");
const config_1 = require("../../config");
const CleanFaresCommand_1 = require("./CleanFaresCommand");
const ShowHelpCommand_1 = require("./ShowHelpCommand");
const OutputGTFSCommand_1 = require("./OutputGTFSCommand");
const CIFRepository_1 = require("../gtfs/repository/CIFRepository");
const station_coordinates_1 = require("../../config/gtfs/station-coordinates");
const FileOutput_1 = require("../gtfs/output/FileOutput");
const OutputGTFSZipCommand_1 = require("./OutputGTFSZipCommand");
const DownloadCommand_1 = require("./DownloadCommand");
const DownloadAndProcessCommand_1 = require("./DownloadAndProcessCommand");
const GTFSImportCommand_1 = require("./GTFSImportCommand");
const nfm64_1 = require("../../config/nfm64");
const DownloadFileCommand_1 = require("./DownloadFileCommand");
const PromiseSFTP_1 = require("../sftp/PromiseSFTP");
class Container {
    getCommand(type) {
        switch (type) {
            case "--fares": return this.getFaresImportCommand();
            case "--fares-clean": return this.getCleanFaresCommand();
            case "--routeing": return this.getRouteingImportCommand();
            case "--timetable": return this.getTimetableImportCommand();
            case "--nfm64": return this.getNFM64ImportCommand();
            case "--gtfs": return this.getOutputGTFSCommand();
            case "--gtfs-import": return this.getImportGTFSCommand();
            case "--gtfs-zip": return this.getOutputGTFSZipCommand();
            case "--download-fares": return this.getDownloadCommand("/fares/");
            case "--download-timetable": return this.getDownloadCommand("/timetable/");
            case "--download-routeing": return this.getDownloadCommand("/routing_guide/");
            case "--download-nfm64": return this.getDownloadNFM64Command();
            case "--get-fares": return this.getDownloadAndProcessCommand("/fares/", this.getFaresImportCommand());
            case "--get-timetable": return this.getDownloadAndProcessCommand("/timetable/", this.getTimetableImportCommand());
            case "--get-routeing": return this.getDownloadAndProcessCommand("/routing_guide/", this.getRouteingImportCommand());
            case "--get-nfm64": return this.getDownloadAndProcessNFM64Command();
            default: return this.getShowHelpCommand();
        }
    }
    async getFaresImportCommand() {
        return new ImportFeedCommand_1.ImportFeedCommand(await this.getDatabaseConnection(), config_1.default.fares, "/tmp/dtd/fares/");
    }
    async getRouteingImportCommand() {
        return new ImportFeedCommand_1.ImportFeedCommand(await this.getDatabaseConnection(), config_1.default.routeing, "/tmp/dtd/routeing/");
    }
    async getTimetableImportCommand() {
        return new ImportFeedCommand_1.ImportFeedCommand(await this.getDatabaseConnection(), config_1.default.timetable, "/tmp/dtd/timetable/");
    }
    async getNFM64ImportCommand() {
        return new ImportFeedCommand_1.ImportFeedCommand(await this.getDatabaseConnection(), config_1.default.nfm64, "/tmp/dtd/nfm64/");
    }
    async getCleanFaresCommand() {
        return new CleanFaresCommand_1.CleanFaresCommand(await this.getDatabaseConnection());
    }
    async getShowHelpCommand() {
        return new ShowHelpCommand_1.ShowHelpCommand();
    }
    getImportGTFSCommand() {
        return Promise.resolve(new GTFSImportCommand_1.GTFSImportCommand(this.databaseConfiguration));
    }
    getOutputGTFSCommandWithOutput(output) {
        return new OutputGTFSCommand_1.OutputGTFSCommand(new CIFRepository_1.CIFRepository(this.getDatabaseConnection(), this.getDatabaseStream(), station_coordinates_1.stationCoordinates), output);
    }
    async getOutputGTFSCommand() {
        return this.getOutputGTFSCommandWithOutput(new FileOutput_1.FileOutput());
    }
    async getOutputGTFSZipCommand() {
        return new OutputGTFSZipCommand_1.OutputGTFSZipCommand(await this.getOutputGTFSCommand());
    }
    async getDownloadCommand(path) {
        return new DownloadCommand_1.DownloadCommand(await this.getDatabaseConnection(), await this.getSFTP(), path);
    }
    async getDownloadNFM64Command() {
        return Promise.resolve(new DownloadFileCommand_1.DownloadFileCommand(nfm64_1.downloadUrl));
    }
    async getDownloadAndProcessCommand(path, process) {
        return new DownloadAndProcessCommand_1.DownloadAndProcessCommand(await this.getDownloadCommand(path), await process);
    }
    async getDownloadAndProcessNFM64Command() {
        return new DownloadAndProcessCommand_1.DownloadAndProcessCommand(await this.getDownloadNFM64Command(), await this.getNFM64ImportCommand());
    }
    getSFTP() {
        return PromiseSFTP_1.PromiseSFTP.connect({
            host: process.env.SFTP_HOSTNAME || "dtd.atocrsp.org",
            username: process.env.SFTP_USERNAME,
            password: process.env.SFTP_PASSWORD,
            algorithms: {
                kex: [
                    "diffie-hellman-group1-sha1",
                    "ecdh-sha2-nistp256",
                    "ecdh-sha2-nistp384",
                    "ecdh-sha2-nistp521",
                    "diffie-hellman-group-exchange-sha256",
                    "diffie-hellman-group14-sha1"
                ],
                cipher: [
                    "3des-cbc",
                    "aes128-ctr",
                    "aes192-ctr",
                    "aes256-ctr",
                    "aes128-gcm",
                    "aes128-gcm@openssh.com",
                    "aes256-gcm",
                    "aes256-gcm@openssh.com"
                ],
                serverHostKey: [
                    "ssh-dss",
                    "ssh-rsa",
                    "ecdsa-sha2-nistp256",
                    "ecdsa-sha2-nistp384",
                    "ecdsa-sha2-nistp521"
                ],
                hmac: [
                    "hmac-sha2-256",
                    "hmac-sha2-512",
                    "hmac-sha1"
                ]
            }
        });
    }
    getDatabaseConnection() {
        return require('mysql2/promise').createPool(Object.assign({}, this.databaseConfiguration));
    }
    getDatabaseStream() {
        return require('mysql2').createPool(this.databaseConfiguration);
    }
    get databaseConfiguration() {
        if (!process.env.DATABASE_NAME) {
            throw new Error("Please set the DATABASE_NAME environment variable.");
        }
        return {
            host: process.env.DATABASE_HOSTNAME || "localhost",
            user: process.env.DATABASE_USERNAME || "root",
            password: process.env.DATABASE_PASSWORD || null,
            database: process.env.DATABASE_NAME,
            port: +(process.env.DATABASE_PORT || 3306),
            connectionLimit: 20,
            multipleStatements: true
        };
    }
}
exports.Container = Container;
__decorate([
    memoize
], Container.prototype, "getCommand", null);
__decorate([
    memoize
], Container.prototype, "getFaresImportCommand", null);
__decorate([
    memoize
], Container.prototype, "getRouteingImportCommand", null);
__decorate([
    memoize
], Container.prototype, "getTimetableImportCommand", null);
__decorate([
    memoize
], Container.prototype, "getNFM64ImportCommand", null);
__decorate([
    memoize
], Container.prototype, "getCleanFaresCommand", null);
__decorate([
    memoize
], Container.prototype, "getShowHelpCommand", null);
__decorate([
    memoize
], Container.prototype, "getImportGTFSCommand", null);
__decorate([
    memoize
], Container.prototype, "getOutputGTFSCommandWithOutput", null);
__decorate([
    memoize
], Container.prototype, "getOutputGTFSCommand", null);
__decorate([
    memoize
], Container.prototype, "getOutputGTFSZipCommand", null);
__decorate([
    memoize
], Container.prototype, "getDownloadCommand", null);
__decorate([
    memoize
], Container.prototype, "getDownloadNFM64Command", null);
__decorate([
    memoize
], Container.prototype, "getDownloadAndProcessCommand", null);
__decorate([
    memoize
], Container.prototype, "getDownloadAndProcessNFM64Command", null);
__decorate([
    memoize
], Container.prototype, "getSFTP", null);
__decorate([
    memoize
], Container.prototype, "getDatabaseConnection", null);
__decorate([
    memoize
], Container.prototype, "getDatabaseStream", null);
//# sourceMappingURL=Container.js.map