"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DownloadCommand = void 0;
class DownloadCommand {
    constructor(db, sftp, directory) {
        this.db = db;
        this.sftp = sftp;
        this.directory = directory;
    }
    /**
     * Download the latest refresh file from an SFTP server
     */
    async run(argv) {
        const outputDirectory = argv[3] || "/tmp/";
        const [remoteFiles, lastProcessedFile] = await Promise.all([
            this.sftp.readdir(this.directory),
            this.getLastProcessedFile()
        ]);
        const files = this.getFilesToProcess(remoteFiles, lastProcessedFile);
        if (files.length > 0) {
            console.log(`Downloading ${files.length} feed file(s)`);
        }
        else {
            console.log("No files to update.");
        }
        try {
            await Promise.all(files.map(f => this.sftp.fastGet(this.directory + f, outputDirectory + f, { concurrency: 1 })));
        }
        catch (err) {
            console.error(err);
        }
        this.sftp.end();
        return files.map(filename => outputDirectory + filename);
    }
    async getLastProcessedFile() {
        try {
            const [[log]] = await this.db.query("SELECT * FROM log ORDER BY id DESC LIMIT 1");
            return log.filename !== null ? log.filename : undefined;
        }
        catch (err) {
            return undefined;
        }
    }
    /**
     * Do a directory listing to get the filename of the last full refresh
     */
    getFilesToProcess(dir, lastProcessed) {
        dir.sort((a, b) => b.attrs.mtime - a.attrs.mtime);
        const lastRefresh = dir.findIndex(i => i.filename.charAt(4) === "F" || i.filename.startsWith("RJRG"));
        const lastFile = dir.findIndex(i => i.filename === lastProcessed);
        const files = lastFile > -1 && (lastFile <= lastRefresh || lastRefresh < 0)
            ? dir.slice(0, lastFile)
            : dir.slice(0, lastRefresh + 1);
        return files.map(f => f.filename).reverse();
    }
}
exports.DownloadCommand = DownloadCommand;
//# sourceMappingURL=DownloadCommand.js.map