"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MySQLStream = void 0;
const stream_1 = require("stream");
class MySQLStream extends stream_1.Writable {
    constructor(filename, file, tables) {
        super({ decodeStrings: false });
        this.filename = filename;
        this.file = file;
        this.tables = tables;
    }
    async _write(line, encoding, callback) {
        if (line === "" || line.charAt(0) === "/") {
            return callback();
        }
        try {
            const record = this.file.getRecord(line);
            if (record) {
                await this.tables[record.name].apply(record.extractValues(line));
            }
            callback();
        }
        catch (err) {
            callback(Error(`Error processing ${this.filename} with data ${line}` + err.stack));
        }
    }
    async _final(callback) {
        try {
            await Promise.all(Object.values(this.tables).map(t => t.close()));
            callback();
        }
        catch (err) {
            callback(err);
        }
    }
}
exports.MySQLStream = MySQLStream;
//# sourceMappingURL=MySQLStream.js.map