"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NullDateField = exports.ShortDateField = exports.DateField = void 0;
const Field_1 = require("./Field");
/**
 * DTD date field (e.g. 3112999)
 */
class DateField extends Field_1.Field {
    constructor(start, nullable = false) {
        super(start, 8, nullable, [" ", "*", "0"]);
    }
    /**
     * Turn a DTD formatted date into a MySQL formatted date
     */
    parse(value) {
        return `${value.substr(4, 4)}-${value.substr(2, 2)}-${value.substr(0, 2)}`;
    }
}
exports.DateField = DateField;
/**
 * Short format DTD date (e.g. 170531)
 */
class ShortDateField extends Field_1.Field {
    constructor(start, nullable = false) {
        super(start, 6, nullable, [" ", "*", "0"]);
    }
    /**
     * Turn a DTD formatted date into a MySQL formatted date
     */
    parse(value) {
        if (value === "999999")
            return "2099-12-31";
        else
            return `20${value.substr(0, 2)}-${value.substr(2, 2)}-${value.substr(4, 2)}`;
    }
}
exports.ShortDateField = ShortDateField;
/**
 * Placeholder date for the restriction date columns
 */
class NullDateField extends Field_1.Field {
    constructor() {
        super(0, 0, true, [""]);
    }
    /**
     * Always return null
     */
    parse(value) {
        return null;
    }
}
exports.NullDateField = NullDateField;
//# sourceMappingURL=DateField.js.map