/**
 * Parent class for all fields
 */
export declare abstract class Field {
    readonly position: number;
    readonly length: number;
    readonly nullable: boolean;
    readonly nullChars: string[];
    constructor(position: number, length: number, nullable?: boolean, nullChars?: string[]);
    /**
     * Return the possible null values for this field. For example, if the nullChars are " " and "*" and the length
     * is 3 this method will return ["   ", "***"]
     */
    get nullValues(): string[];
    /**
     * Do some null checking then offload to the sub classes parse method
     */
    extract(value: string): FieldValue;
    protected abstract parse(value: string): FieldValue;
}
export declare class ParseError extends Error {
}
export type FieldValue = null | string | number;
