"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParseError = exports.Field = void 0;
const util_1 = require("util");
const memoize = require("memoized-class-decorator");
/**
 * Parent class for all fields
 */
class Field {
    constructor(position, length, nullable = false, nullChars = [" ", "*"]) {
        this.position = position;
        this.length = length;
        this.nullable = nullable;
        this.nullChars = nullChars;
    }
    /**
     * Return the possible null values for this field. For example, if the nullChars are " " and "*" and the length
     * is 3 this method will return ["   ", "***"]
     */
    get nullValues() {
        return this.nullChars.map(c => Array(this.length + 1).join(c));
    }
    /**
     * Do some null checking then offload to the sub classes parse method
     */
    extract(value) {
        const isNull = (0, util_1.isNullOrUndefined)(value) || value === "" || this.nullValues.indexOf(value) > -1;
        if (isNull) {
            if (this.nullable)
                return null;
            else
                throw new ParseError(`Non-nullable field received null value: "${value}" at position ${this.position}`);
        }
        return this.parse(value);
    }
}
exports.Field = Field;
__decorate([
    memoize
], Field.prototype, "nullValues", null);
class ParseError extends Error {
}
exports.ParseError = ParseError;
//# sourceMappingURL=Field.js.map