import { FieldMap, ParsedRecord, Record, RecordAction } from "./Record";
/**
 * Record with fixed with fields
 */
export declare class FixedWidthRecord implements Record {
    readonly name: string;
    readonly key: string[];
    readonly fields: FieldMap;
    readonly indexes: string[];
    readonly actionMap: ActionMap;
    readonly charPosition: number;
    readonly orderedInserts: boolean;
    constructor(name: string, key: string[], fields: FieldMap, indexes?: string[], actionMap?: ActionMap, charPosition?: number, orderedInserts?: boolean);
    /**
     * Extract the relevant part of the line for each field and then get the value from the field
     */
    extractValues(line: string): ParsedRecord;
}
/**
 * Different feeds use different characters for different actions, this map provides a look up from char to action
 */
export interface ActionMap {
    [char: string]: RecordAction;
}
/**
 * This record type uses a generated integer rather than the standard auto_increment. The only reason to do this use
 * this record type is to reference a row in another table that has not been inserted yet see {@link ForeignKeyField}
 */
export declare class RecordWithManualIdentifier extends FixedWidthRecord {
    lastId: number;
    extractValues(line: string): ParsedRecord;
}
