"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecordWithManualIdentifier = exports.FixedWidthRecord = void 0;
const Record_1 = require("./Record");
/**
 * Record with fixed with fields
 */
class FixedWidthRecord {
    constructor(name, key, fields, indexes = [], actionMap = {}, charPosition = 0, orderedInserts = false) {
        this.name = name;
        this.key = key;
        this.fields = fields;
        this.indexes = indexes;
        this.actionMap = actionMap;
        this.charPosition = charPosition;
        this.orderedInserts = orderedInserts;
    }
    /**
     * Extract the relevant part of the line for each field and then get the value from the field
     */
    extractValues(line) {
        const action = this.actionMap[line.charAt(this.charPosition)] || Record_1.RecordAction.Insert;
        const values = { id: null };
        for (const key of Object.keys(this.fields)) {
            values[key] = this.fields[key].extract(line.substr(this.fields[key].position, this.fields[key].length));
        }
        const keysValues = this.key.reduce((vals, key) => {
            vals[key] = values[key];
            return vals;
        }, {});
        return { action, values, keysValues };
    }
}
exports.FixedWidthRecord = FixedWidthRecord;
/**
 * This record type uses a generated integer rather than the standard auto_increment. The only reason to do this use
 * this record type is to reference a row in another table that has not been inserted yet see {@link ForeignKeyField}
 */
class RecordWithManualIdentifier extends FixedWidthRecord {
    constructor() {
        super(...arguments);
        this.lastId = 0;
    }
    extractValues(line) {
        const action = this.actionMap[line.charAt(this.charPosition)] || Record_1.RecordAction.Insert;
        const values = action === Record_1.RecordAction.Delete ? {} : { id: ++this.lastId };
        for (const key in this.fields) {
            values[key] = this.fields[key].extract(line.substr(this.fields[key].position, this.fields[key].length));
        }
        const keysValues = this.key.reduce((vals, key) => {
            vals[key] = values[key];
            return vals;
        }, {});
        return { action, values, keysValues };
    }
}
exports.RecordWithManualIdentifier = RecordWithManualIdentifier;
//# sourceMappingURL=FixedWidthRecord.js.map