"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultiFormatRecord = void 0;
const Record_1 = require("./Record");
/**
 * Record that has multiple row types, used for LI, LO stop records
 */
class MultiFormatRecord {
    constructor(name, key, fields, records, recordIdentifierStart, recordIdentifierLength, indexes = [], orderedInserts = false) {
        this.name = name;
        this.key = key;
        this.fields = fields;
        this.records = records;
        this.recordIdentifierStart = recordIdentifierStart;
        this.recordIdentifierLength = recordIdentifierLength;
        this.indexes = indexes;
        this.orderedInserts = orderedInserts;
        this.lastId = 0;
    }
    /**
     * Extract the relevant part of the line for each field and then get the value from the field
     */
    extractValues(line) {
        const type = line.substr(this.recordIdentifierStart, this.recordIdentifierLength);
        const record = this.records[type];
        const values = { id: ++this.lastId };
        const action = Record_1.RecordAction.Insert;
        for (const key in record) {
            values[key] = record[key].extract(line.substr(record[key].position, record[key].length));
        }
        return { action, values, keysValues: values };
    }
}
exports.MultiFormatRecord = MultiFormatRecord;
//# sourceMappingURL=MultiFormatRecord.js.map