"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyOverlays = void 0;
const OverlayRecord_1 = require("../native/OverlayRecord");
const ScheduleCalendar_1 = require("../native/ScheduleCalendar");
/**
 * Index the schedules by TUID, detect overlays and create new schedules as necessary.
 */
function applyOverlays(schedules, idGenerator = getDefaultIdGenerator()) {
    const schedulesByTuid = {};
    for (const schedule of schedules) {
        // for all cancellation or overlays (perms don't overlap)
        if (schedule.stp !== OverlayRecord_1.STP.Permanent) {
            // get any schedules that share the same TUID
            for (const baseSchedule of schedulesByTuid[schedule.tuid] || []) {
                // remove the underlying schedule and add the replacement(s)
                schedulesByTuid[schedule.tuid].splice(schedulesByTuid[schedule.tuid].indexOf(baseSchedule), 1, ...applyOverlay(baseSchedule, schedule, idGenerator));
            }
        }
        // add the schedule to the index, unless it's a cancellation
        if (schedule.stp !== OverlayRecord_1.STP.Cancellation) {
            (schedulesByTuid[schedule.tuid] = schedulesByTuid[schedule.tuid] || []).push(schedule);
        }
    }
    return schedulesByTuid;
}
exports.applyOverlays = applyOverlays;
/**
 * Return a Iterator that generates incremental numbers starting at the given number
 */
function* getDefaultIdGenerator() {
    let id = 0;
    while (true) {
        yield id++;
    }
}
/**
 * Check if the given schedule overlaps the current one and if necessary divide this schedule into many others.
 *
 * If there is no overlap this Schedule will be returned intact.
 */
function applyOverlay(base, overlay, ids) {
    const overlap = base.calendar.getOverlap(overlay.calendar);
    // if this schedules schedule overlaps it at any point
    if (overlap === ScheduleCalendar_1.OverlapType.None) {
        return [base];
    }
    return overlap === ScheduleCalendar_1.OverlapType.Short
        ? base.calendar.addExcludeDays(overlay.calendar).map(calendar => base.clone(calendar, base.id))
        : base.calendar.divideAround(overlay.calendar).map(calendar => base.clone(calendar, ids.next().value));
}
//# sourceMappingURL=ApplyOverlays.js.map