/// <reference types="node" />
import { Client, ConnectConfig, FileEntry, SFTPWrapper, TransferOptions } from "ssh2";
/**
 * Wrapper around the ssh2 client
 */
export declare class PromiseSFTP {
    constructor(sftp: SFTPWrapper, client: Client);
    /**
     * Connect to an SFTP server and return a PromiseSFTP client
     */
    static connect(config: ConnectConfig): Promise<PromiseSFTP>;
    /**
     * Read the contents of the given directory. Promisified version of ssh2's readdir method.
     */
    readdir: (path: string | Buffer) => Promise<FileEntry[]>;
    /**
     * Copy file from source to destination. Promisified version of ssh2's fastGet
     */
    fastGet: (from: string, to: string, opts?: TransferOptions) => Promise<void>;
    /**
     * Close the underlying SFTP connection
     */
    end: () => void;
}
