"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PromiseSFTP = void 0;
const ssh2_1 = require("ssh2");
const util_1 = require("util");
/**
 * Wrapper around the ssh2 client
 */
class PromiseSFTP {
    constructor(sftp, client) {
        this.readdir = (0, util_1.promisify)(sftp.readdir.bind(sftp));
        this.fastGet = (0, util_1.promisify)(sftp.fastGet.bind(sftp));
        this.end = client.end.bind(client);
    }
    /**
     * Connect to an SFTP server and return a PromiseSFTP client
     */
    static connect(config) {
        return new Promise((resolve, reject) => {
            const client = new ssh2_1.Client();
            client.on("error", reject);
            client.on("ready", () => {
                client.sftp((err, sftp) => {
                    if (err) {
                        reject(err);
                    }
                    resolve(new PromiseSFTP(sftp, client));
                });
            });
            client.connect(config);
        });
    }
}
exports.PromiseSFTP = PromiseSFTP;
//# sourceMappingURL=PromiseSFTP.js.map